@@ -2,9 +2,7 @@ package Plack::Middleware::BlockHeaderInjection;
 
 # ABSTRACT: block header injections in responses
 
-use v5.8;
-
-use strict;
+use v5.12;
 use warnings;
 
 use parent qw( Plack::Middleware );
@@ -12,15 +10,15 @@ use parent qw( Plack::Middleware );
 use Plack::Util;
 use Plack::Util::Accessor qw( logger status );
 
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.1.0';
 
 
 sub call {
     my ( $self, $env ) = @_;
 
     # cache the logger
-    $self->logger($env->{'psgix.logger'} || sub { })
-        unless defined $self->logger;
+    $self->logger( $env->{'psgix.logger'} || sub { } )
+      unless defined $self->logger;
 
     $self->status(500) unless $self->status;
 
@@ -36,16 +34,15 @@ sub call {
             my $hdrs = $res->[1];
 
             my $i = 0;
-            while ($i < @{$hdrs}) {
-                my $val = $hdrs->[$i+1];
-                if ($val =~ /[\n\r]/) {
+            while ( $i < @{$hdrs} ) {
+                my $val = $hdrs->[ $i + 1 ];
+                if ( $val =~ /[\n\r]/ ) {
                     my $key = $hdrs->[$i];
-                    $self->log(
-                        error => "possible header injection detected in ${key}" );
+                    $self->log( error => "possible header injection detected in ${key}" );
                     $res->[0] = $self->status;
-                    Plack::Util::header_remove($hdrs, $key);
+                    Plack::Util::header_remove( $hdrs, $key );
                 }
-                $i+=2;
+                $i += 2;
             }
 
         }
@@ -57,11 +54,13 @@ sub call {
 
 
 sub log {
-    my ($self, $level, $msg) = @_;
-    $self->logger->({
-        level   => $level,
-        message => "BlockHeaderInjection: ${msg}",
-    });
+    my ( $self, $level, $msg ) = @_;
+    $self->logger->(
+        {
+            level   => $level,
+            message => "BlockHeaderInjection: ${msg}",
+        }
+    );
 }
 
 
@@ -79,7 +78,7 @@ Plack::Middleware::BlockHeaderInjection - block header injections in responses
 
 =head1 VERSION
 
-version v1.0.1
+version v1.1.0
 
 =head1 SYNOPSIS
 
@@ -114,6 +113,15 @@ this is C<500>.
 
 =for Pod::Coverage log
 
+=head1 SUPPORT FOR OLDER PERL VERSIONS
+
+Since v1.1.0, this module requires Perl v5.12 or later.
+
+Future releases may only support Perl versions released in the last ten years.
+
+If you need this module on Perl v5.8, please use one of the v1.0.x versions of this module.  Signficant bug or security
+fixes may be backported to those versions.
+
 =head1 SEE ALSO
 
 L<https://en.wikipedia.org/wiki/HTTP_header_injection>
@@ -141,7 +149,7 @@ Foxtons, Ltd L<https://www.foxtons.co.uk>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014,2020 by Robert Rothenberg.
+This software is Copyright (c) 2014,2020,2023 by Robert Rothenberg.
 
 This is free software, licensed under:
 
